==> mule-runtime-extension-model-4.6.25-20251030.172215-6-sources.jar: org/mule/runtime/config/internal/validation/ReferenceParametersStereotypesValidations.java <==
/*
 * Copyright 2023 Salesforce, Inc. All rights reserved.
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.runtime.config.internal.validation;

import static org.mule.runtime.ast.api.validation.Validation.Level.WARN;
import static org.mule.runtime.config.internal.validation.FlowRefPointsToExistingFlow.FLOW_REF_IDENTIFIER;
import static org.mule.runtime.extension.api.stereotype.MuleStereotypes.APP_CONFIG;
import static org.mule.runtime.extension.api.stereotype.MuleStereotypes.CONFIG;

import org.mule.runtime.ast.api.ArtifactAst;
import org.mule.runtime.ast.graph.api.ArtifactAstDependencyGraphProvider;
import org.mule.runtime.ast.graph.api.ComponentAstDependency;

import java.util.function.Predicate;

public class ReferenceParametersStereotypesValidations extends AbstractReferenceParametersStereotypesValidations {

  public ReferenceParametersStereotypesValidations(ArtifactAstDependencyGraphProvider artifactAstDependencyGraphProvider) {
    super(artifactAstDependencyGraphProvider);
  }

  @Override
  public String getName() {
    return "Reference parameters stereotypes";
  }

  @Override
  public String getDescription() {
    return "Reference parameters point to declarations of the appropriate stereotype.";
  }

  @Override
  public Level getLevel() {
    // Keep backwards compatibility with some scenarios that are expected to deploy and fail at runtime rather than deployment
    return WARN;
  }

  @Override
  protected Predicate<? super ComponentAstDependency> filterArtifact(ArtifactAst artifact) {
    return missing ->
    // flow-ref is already validated by FlowRefPointsToExistingFlow
    !missing.getComponent().getIdentifier().equals(FLOW_REF_IDENTIFIER)
        && missing.getAllowedStereotypes().stream()
            .noneMatch(st -> st.isAssignableTo(CONFIG)
                || st.isAssignableTo(APP_CONFIG));
  }

}

==> mule-runtime-extension-model-4.11.0-20251202.200838-187-sources.jar: org/mule/runtime/config/internal/validation/ReferenceParametersStereotypesValidations.java <==
/*
 * Copyright 2023 Salesforce, Inc. All rights reserved.
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.runtime.config.internal.validation;

import static org.mule.runtime.ast.api.validation.Validation.Level.WARN;
import static org.mule.runtime.config.internal.validation.DefaultErrorHandlerPointsToExistingErrorHandler.CONFIGURATION_IDENTIFIER;
import static org.mule.runtime.config.internal.validation.FlowRefPointsToExistingFlow.FLOW_REF_IDENTIFIER;
import static org.mule.runtime.extension.api.stereotype.MuleStereotypes.APP_CONFIG;
import static org.mule.runtime.extension.api.stereotype.MuleStereotypes.CONFIG;

import org.mule.runtime.ast.api.ArtifactAst;
import org.mule.runtime.ast.graph.api.ArtifactAstDependencyGraphProvider;
import org.mule.runtime.ast.graph.api.ComponentAstDependency;

import java.util.function.Predicate;

public class ReferenceParametersStereotypesValidations extends AbstractReferenceParametersStereotypesValidations {

  public ReferenceParametersStereotypesValidations(ArtifactAstDependencyGraphProvider artifactAstDependencyGraphProvider) {
    super(artifactAstDependencyGraphProvider);
  }

  @Override
  public String getName() {
    return "Reference parameters stereotypes";
  }

  @Override
  public String getDescription() {
    return "Reference parameters point to declarations of the appropriate stereotype.";
  }

  @Override
  public Level getLevel() {
    // Keep backwards compatibility with some scenarios that are expected to deploy and fail at runtime rather than deployment
    return WARN;
  }

  @Override
  protected Predicate<? super ComponentAstDependency> filterArtifact(ArtifactAst artifact) {
    return missing ->
    // flow-ref is already validated by FlowRefPointsToExistingFlow
    !missing.getComponent().getIdentifier().equals(FLOW_REF_IDENTIFIER)
        // configuration.defaultErrorHandler-ref is already validated by DefaultErrorHandlerPointsToExistingErrorHandler
        // configuration.defaultObjectSerializer-ref is already validated by DefaultObjectSerializerPointsToExistingSerializer
        && !missing.getComponent().getIdentifier().equals(CONFIGURATION_IDENTIFIER)
        && missing.getAllowedStereotypes().stream()
            .noneMatch(st -> st.isAssignableTo(CONFIG)
                || st.isAssignableTo(APP_CONFIG));
  }

}
